@@ -276,6 +276,21 @@ bool DbAccess::checkDbSchema()
         return false;
     }
 
+    db.exec("CREATE TABLE IF NOT EXISTS custom_lessons ("
+            "id TEXT PRIMARY KEY, "
+            "profile_id INTEGER, "
+            "title TEXT, "
+            "text TEXT, "
+            "keyboard_layout_name TEXT "
+            ")");
+
+    if (db.lastError().isValid())
+    {
+        kWarning() << db.lastError().text();
+        raiseError(db.lastError());
+        return false;
+    }
+
     return true;
 }
 
@@ -362,7 +377,7 @@ bool DbAccess::migrateFrom1_0To1_1()
 
     updateIdQuery.prepare("UPDATE course_lessons SET id = ? WHERE id = ?");
 
-    foreach (const QString id, ids)
+    foreach (const QString& id, ids)
     {
         updateIdQuery.bindValue(0, QUuid::createUuid().toString());
         updateIdQuery.bindValue(1, id);
