@@ -29,7 +29,7 @@
 #include "core/specialkey.h"
 #include "undocommands/keyboardlayoutcommands.h"
 #include "models/charactersmodel.h"
-#include "editor/charactersvieweditorfactories.h"
+#include "editor/charactersviewdelegate.h"
 
 KeyboardLayoutPropertiesWidget::KeyboardLayoutPropertiesWidget(QWidget* parent) :
     QWidget(parent),
@@ -39,7 +39,7 @@ KeyboardLayoutPropertiesWidget::KeyboardLayoutPropertiesWidget(QWidget* parent)
     m_readOnly(false),
     m_undoStack(0),
     m_charactersModel(new CharactersModel(this)),
-    m_charModifierIdEditorFactory(new CharacterModifierIdEditorFactory())
+    m_charactersViewDelegate(new CharactersViewDelegate(this))
 {
     setupUi(this);
     setFont(KGlobalSettings::smallestReadableFont());
@@ -47,15 +47,7 @@ KeyboardLayoutPropertiesWidget::KeyboardLayoutPropertiesWidget(QWidget* parent)
     setSelectedKey(-1);
 
     m_charactersView->setModel(m_charactersModel);
-    QStyledItemDelegate* charValueDelegate = new QStyledItemDelegate(m_charactersView);
-    charValueDelegate->setItemEditorFactory(new CharacterValueEditorFactory());
-    m_charactersView->setItemDelegateForColumn(0, charValueDelegate);
-    QStyledItemDelegate* charModifierIdDelegate = new QStyledItemDelegate(m_charactersView);
-    charModifierIdDelegate->setItemEditorFactory(m_charModifierIdEditorFactory);
-    m_charactersView->setItemDelegateForColumn(1, charModifierIdDelegate);
-    QStyledItemDelegate* charPositionDelegate = new QStyledItemDelegate(m_charactersView);
-    charPositionDelegate->setItemEditorFactory(new CharacterPositionEditorFactory());
-    m_charactersView->setItemDelegateForColumn(2, charPositionDelegate);
+    m_charactersView->setItemDelegate(m_charactersViewDelegate);
     m_charactersView->verticalHeader()->setDefaultSectionSize(m_charactersView->verticalHeader()->minimumSectionSize() + 6);
 
     connect(m_charactersView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), SLOT(onCharacterSelected()));
@@ -86,7 +78,7 @@ void KeyboardLayoutPropertiesWidget::setKeyboardLayout(KeyboardLayout* layout)
     m_keyboardLayout = layout;
 
     m_charactersModel->setKeyboardLayout(layout);
-    m_charModifierIdEditorFactory->setKeyboardLayout(layout);
+    m_charactersViewDelegate->setKeyboardLayout(layout);
 
     connect(m_keyboardLayout, SIGNAL(titleChanged()), SLOT(updateKeyboardLayoutTitle()));
     connect(m_keyboardLayout, SIGNAL(nameChanged()), SLOT(updateKeyboardLayoutName()));
